@@ -4,7 +4,7 @@ import pandas as pd
 import numpy as np
 from pyparsing import col
 
-def basic_table(read_path, read_type='csv', sheet_name=None, columns_to_keep=None, columns_rename=None, 
+def basic_table(read_path, read_type='csv', sheet_name=None, columns_to_keep='all', columns_rename=None, 
                 filters=None, group_by=None, aggregate_columns=None, pre_agg_math_columns=None, 
                 post_agg_math_columns=None, remove_NAN=True, remove_NAN_col='all'):
     
@@ -15,9 +15,9 @@ def basic_table(read_path, read_type='csv', sheet_name=None, columns_to_keep=Non
     else:
         print('read_type must be either "csv" or "excel"')
     
-    if columns_to_keep is not None:
+    if columns_to_keep != 'all':
         df_basic_table = df_basic_table[columns_to_keep]
-    if columns_to_keep is not None:
+    if columns_rename is not None:
         df_basic_table.columns = columns_rename
     
     if remove_NAN:
